# frozen_string_literal: true

class RemoveDuplicatedCsFindingsWithoutVulnerabilityId < ActiveRecord::Migration[6.0]
  include Gitlab::Database::MigrationHelpers

  DOWNTIME = false

  disable_ddl_transaction!

  BATCH_SIZE = 1_000

  INTERVAL = 2.minutes

  # 1_500 records will be deleted
  def up
    return unless Gitlab.com?

    migration = Gitlab::BackgroundMigration::RemoveDuplicatedCsFindingsWithoutVulnerabilityId
    migration_name = migration.to_s.demodulize
    relation = migration::Finding.container_scanning.with_broken_fingerprint.where(vulnerability_id: nil)
    queue_background_migration_jobs_by_range_at_intervals(relation,
                                                            migration_name,
                                                            INTERVAL,
                                                            batch_size: BATCH_SIZE)
  end

  def down
    # no-op
  end
end
